@@ -310,7 +310,7 @@ typedef struct sfm			/* SDLA firmware file structire */
 		(adapter_type == AFT_ADPTR_4SERIAL_V35X21) ? "AFT-A144" : \
 		(adapter_type == AFT_ADPTR_2SERIAL_RS232)  ? "AFT-A142" : \
 		(adapter_type == AFT_ADPTR_4SERIAL_RS232)  ? "AFT-A144" : \
-		(adapter_type == AFT_ADPTR_A600)           ? "AFT-A600" : \
+		(adapter_type == AFT_ADPTR_A600)           ? "AFT-B600" : \
 							     "UNKNOWN"
 			
 #define AFT_GET_SECURITY(security)					\
